==> jc-1.4.0.tar.gz: java/rmi/activation/ActivateFailedException.h <==
// public class java.rmi.activation.ActivateFailedException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class d78eaa890ba1760c java_rmi_activation_ActivateFailedException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_activation_ActivateFailedException_H_
#define _JC_java_rmi_activation_ActivateFailedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivateFailedException$sub_refs	_jc_java_rmi_activation_ActivateFailedException$sub_refs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$sub_nonrefs	_jc_java_rmi_activation_ActivateFailedException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$refs	_jc_java_rmi_activation_ActivateFailedException$refs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$nonrefs	_jc_java_rmi_activation_ActivateFailedException$nonrefs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$object	_jc_java_rmi_activation_ActivateFailedException$object;

typedef struct _jc_java_rmi_activation_ActivateFailedException$fields_struct	_jc_java_rmi_activation_ActivateFailedException$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivateFailedException$vmethods	_jc_java_rmi_activation_ActivateFailedException$vmethods;
typedef const struct _jc_java_rmi_activation_ActivateFailedException$vtable	_jc_java_rmi_activation_ActivateFailedException$vtable;
typedef const struct _jc_java_rmi_activation_ActivateFailedException$vtype	_jc_java_rmi_activation_ActivateFailedException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivateFailedException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivateFailedException$fields_struct _jc_java_rmi_activation_ActivateFailedException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivateFailedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_ActivateFailedException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_activation_ActivateFailedException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_activation_ActivateFailedException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_java_rmi_activation_ActivateFailedException$vmethods {
};

// Vtable
struct _jc_java_rmi_activation_ActivateFailedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_activation_ActivateFailedException$vmethods	java_rmi_activation_ActivateFailedException;
};

// Vtype
struct _jc_java_rmi_activation_ActivateFailedException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivateFailedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivateFailedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivateFailedException$refs {
    _jc_java_rmi_activation_ActivateFailedException$sub_refs	java_rmi_activation_ActivateFailedException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivateFailedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivateFailedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_activation_ActivateFailedException$sub_nonrefs	java_rmi_activation_ActivateFailedException;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivateFailedException$object {
	_jc_java_rmi_activation_ActivateFailedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivateFailedException$vtype	*vtype;
	_jc_java_rmi_activation_ActivateFailedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivateFailedException$vtype _jc_java_rmi_activation_ActivateFailedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivateFailedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivateFailedException$class_object;

#endif	/* _JC_java_rmi_activation_ActivateFailedException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/ActivateFailedException.h <==
// public class java.rmi.activation.ActivateFailedException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 512cf355dcdeb26d java_rmi_RemoteException
// @dep_class d78eaa890ba1760c java_rmi_activation_ActivateFailedException

// header file dependencies
// @dep_header java_rmi_RemoteException

#include "java/rmi/RemoteException.h"

#ifndef _JC_java_rmi_activation_ActivateFailedException_H_
#define _JC_java_rmi_activation_ActivateFailedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivateFailedException$sub_refs	_jc_java_rmi_activation_ActivateFailedException$sub_refs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$sub_nonrefs	_jc_java_rmi_activation_ActivateFailedException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$refs	_jc_java_rmi_activation_ActivateFailedException$refs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$nonrefs	_jc_java_rmi_activation_ActivateFailedException$nonrefs;
typedef struct _jc_java_rmi_activation_ActivateFailedException$object	_jc_java_rmi_activation_ActivateFailedException$object;

typedef struct _jc_java_rmi_activation_ActivateFailedException$fields_struct	_jc_java_rmi_activation_ActivateFailedException$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivateFailedException$vmethods	_jc_java_rmi_activation_ActivateFailedException$vmethods;
typedef const struct _jc_java_rmi_activation_ActivateFailedException$vtable	_jc_java_rmi_activation_ActivateFailedException$vtable;
typedef const struct _jc_java_rmi_activation_ActivateFailedException$vtype	_jc_java_rmi_activation_ActivateFailedException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivateFailedException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivateFailedException$fields_struct _jc_java_rmi_activation_ActivateFailedException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivateFailedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_ActivateFailedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_activation_ActivateFailedException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_rmi_activation_ActivateFailedException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivateFailedException$vmethods {
};

// Vtable
struct _jc_java_rmi_activation_ActivateFailedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_rmi_RemoteException$vmethods	java_rmi_RemoteException;
	_jc_java_rmi_activation_ActivateFailedException$vmethods	java_rmi_activation_ActivateFailedException;
};

// Vtype
struct _jc_java_rmi_activation_ActivateFailedException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivateFailedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivateFailedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivateFailedException$refs {
    _jc_java_rmi_activation_ActivateFailedException$sub_refs	java_rmi_activation_ActivateFailedException;
    _jc_java_rmi_RemoteException$sub_refs	java_rmi_RemoteException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivateFailedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivateFailedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_rmi_RemoteException$sub_nonrefs	java_rmi_RemoteException;
    _jc_java_rmi_activation_ActivateFailedException$sub_nonrefs	java_rmi_activation_ActivateFailedException;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivateFailedException$object {
	_jc_java_rmi_activation_ActivateFailedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivateFailedException$vtype	*vtype;
	_jc_java_rmi_activation_ActivateFailedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivateFailedException$vtype _jc_java_rmi_activation_ActivateFailedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivateFailedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivateFailedException$class_object;

#endif	/* _JC_java_rmi_activation_ActivateFailedException_H_ */
